# coding: utf-8

# flake8: noqa

"""
    Signate API

    API for Signate  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import apis into sdk package
from swagger_client.api.default_api import DefaultApi

# import ApiClient
from swagger_client.api_client import ApiClient
from swagger_client.configuration import Configuration
# import models into sdk package
from swagger_client.models.competition import Competition
from swagger_client.models.competitions import Competitions
from swagger_client.models.download import Download
from swagger_client.models.downloads import Downloads
from swagger_client.models.error import Error
from swagger_client.models.file import File
from swagger_client.models.files import Files
from swagger_client.models.submission_option import SubmissionOption
from swagger_client.models.submission_options import SubmissionOptions
from swagger_client.models.success import Success



#!/usr/bin/python
#
# Copyright 2019 SIGNATE Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# -*- coding: utf-8 -*-
from operator import itemgetter
from signate import info
from swagger_client.rest import ApiException
from tabulate import tabulate
from textwrap import dedent
import click
import json
import os
import swagger_client
import warnings
import wget

api_instance = None


def success(message):
    click.echo(click.style(message, fg='green'))
    exit(0)


def error(message):
    click.echo(click.style(message, fg='red'))


def die(message):
    error(message)
    exit(1)


def get_api_token():
    signate_dir = os.path.expanduser('~/.signate/')
    signate_json = os.path.expanduser(signate_dir + 'signate.json')
    if not os.path.isdir(signate_dir):
        os.makedirs(signate_dir)
    try:
        api_token = json.loads(open(signate_json).read())['api-token']
    except FileNotFoundError:
        message = dedent("""
        Could not find %s.
        Please get the API token from this page: %s
        """ % (signate_json, click.style('https://signate.jp/profile#api-token', fg='blue')))
        die(message)
    except KeyError:
        die('There was no "api-token" key in %s.' % (signate_json))
    return api_token


def set_api_instance(api_token):
    global api_instance
    configuration = swagger_client.Configuration()
    configuration.api_key['Authorization'] = api_token
    configuration.api_key_prefix['Authorization'] = 'Bearer'
    api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))


def set_user_agent():
    global api_instance
    api_instance.api_client.user_agent = info.NAME + '/' + info.VERSION


@click.group()
@click.version_option(version=info.VERSION)
def cli():
    pass


@cli.command()
def list():
    """List competition"""
    api_response = api_instance.get_competitions()
    click.echo(tabulate(api_response['data'], headers='keys', tablefmt='simple', stralign='left'))


@cli.command()
@click.option('-c', '--competition-id', type=int, required=True, help='Specify the id of competitions')
def files(competition_id):
    """List file of competition"""
    api_response = api_instance.get_competition_files(competition_id)
    click.echo(tabulate(api_response['data'], headers='keys', tablefmt='simple', stralign='left'))


@cli.command()
@click.option('-c', '--competition-id', type=int, required=True, help='Specify the id of competitions')
@click.option('-f', '--file-id', type=int, help='Specify id of files')
@click.option('-p', '--path', type=click.Path(exists=True, file_okay=False), help='Specify the download destination')
def download(competition_id, file_id=None, path=None):
    """Download the file of competition"""
    if file_id:
        api_response = api_instance.post_competition_file(competition_id, file_id)
    else:
        api_response = api_instance.post_competition_files(competition_id)
    for file in sorted(api_response['data'], key=itemgetter('size')):
        click.echo(file['name'])
        if path:
            wget.download(file['url'], out=path)
        else:
            wget.download(file['url'])
        click.echo()
    success('\nDownload completed.')


@cli.command()
@click.option('-c', '--competition-id', type=int, required=True, help='Specify the id of competitions')
@click.option('-n', '--note', type=str, help='You can leave the comment')
@click.argument('result-file', type=click.Path(exists=True, dir_okay=False), required=True)
def submit(competition_id, result_file, note=None):
    """Submit a result file to the competition"""
    # TODO API仕様変更後、引数を変更
    SUBMISSION_ANALYSYS = ['100']
    SUBMISSION_APPLICATION = ['100']
    if note:
        api_response = api_instance.post_competition_submit(competition_id,
                                                            result_file,
                                                            SUBMISSION_ANALYSYS,
                                                            SUBMISSION_APPLICATION,
                                                            submission_note=note)
    else:
        api_response = api_instance.post_competition_submit(competition_id,
                                                            result_file,
                                                            SUBMISSION_ANALYSYS,
                                                            SUBMISSION_APPLICATION)
    success(api_response.message)


def accept(competition_id):
    api_response = api_instance.post_competition_agreement(competition_id)
    success(api_response.message)


def confirm(required_agreement):
    prompt_message = dedent("""
    %s
    Please read the terms of use before accepting: %s
    """ % (required_agreement['prompt'], click.style(required_agreement['termsUrl'], fg='blue')))
    if click.confirm(prompt_message):
        accept(required_agreement['competitionId'])
    else:
        pass


def main():
    warnings.filterwarnings(action='ignore')
    api_token = get_api_token()
    set_api_instance(api_token)
    set_user_agent()
    try:
        cli()
    except ApiException as ae:
        response = json.loads(ae.body)
        message = response['message']
        if 'requiredAgreement' in response:
            error(message)
            confirm(response['requiredAgreement'])
        elif 'validations' in response:
            for attr, value in response['validations'].__dict__.items():
                error('%s: %s' % (attr, value))
            die(message)
        elif message:
            die(message)
        else:
            die(str(ae.status) + ' ' + str(ae.reason))



# coding: utf-8

"""
    Signate API

    API for Signate  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class Competition(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'competition_id': 'int',
        'title': 'str',
        'closing': 'datetime',
        'prize': 'str',
        'participants': 'int'
    }

    attribute_map = {
        'competition_id': 'competitionId',
        'title': 'title',
        'closing': 'closing',
        'prize': 'prize',
        'participants': 'participants'
    }

    def __init__(self, competition_id=None, title=None, closing=None, prize=None, participants=None):  # noqa: E501
        """Competition - a model defined in Swagger"""  # noqa: E501

        self._competition_id = None
        self._title = None
        self._closing = None
        self._prize = None
        self._participants = None
        self.discriminator = None

        self.competition_id = competition_id
        self.title = title
        if closing is not None:
            self.closing = closing
        if prize is not None:
            self.prize = prize
        if participants is not None:
            self.participants = participants

    @property
    def competition_id(self):
        """Gets the competition_id of this Competition.  # noqa: E501


        :return: The competition_id of this Competition.  # noqa: E501
        :rtype: int
        """
        return self._competition_id

    @competition_id.setter
    def competition_id(self, competition_id):
        """Sets the competition_id of this Competition.


        :param competition_id: The competition_id of this Competition.  # noqa: E501
        :type: int
        """
        if competition_id is None:
            raise ValueError("Invalid value for `competition_id`, must not be `None`")  # noqa: E501

        self._competition_id = competition_id

    @property
    def title(self):
        """Gets the title of this Competition.  # noqa: E501


        :return: The title of this Competition.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this Competition.


        :param title: The title of this Competition.  # noqa: E501
        :type: str
        """
        if title is None:
            raise ValueError("Invalid value for `title`, must not be `None`")  # noqa: E501

        self._title = title

    @property
    def closing(self):
        """Gets the closing of this Competition.  # noqa: E501


        :return: The closing of this Competition.  # noqa: E501
        :rtype: datetime
        """
        return self._closing

    @closing.setter
    def closing(self, closing):
        """Sets the closing of this Competition.


        :param closing: The closing of this Competition.  # noqa: E501
        :type: datetime
        """

        self._closing = closing

    @property
    def prize(self):
        """Gets the prize of this Competition.  # noqa: E501


        :return: The prize of this Competition.  # noqa: E501
        :rtype: str
        """
        return self._prize

    @prize.setter
    def prize(self, prize):
        """Sets the prize of this Competition.


        :param prize: The prize of this Competition.  # noqa: E501
        :type: str
        """

        self._prize = prize

    @property
    def participants(self):
        """Gets the participants of this Competition.  # noqa: E501


        :return: The participants of this Competition.  # noqa: E501
        :rtype: int
        """
        return self._participants

    @participants.setter
    def participants(self, participants):
        """Sets the participants of this Competition.


        :param participants: The participants of this Competition.  # noqa: E501
        :type: int
        """

        self._participants = participants

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Competition, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Competition):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Signate API

    API for Signate  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from swagger_client.api_client import ApiClient


class DefaultApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_competition_files(self, competition_id, **kwargs):  # noqa: E501
        """Return a list of the competition files.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_competition_files(competition_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int competition_id: (required)
        :return: Files
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_competition_files_with_http_info(competition_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_competition_files_with_http_info(competition_id, **kwargs)  # noqa: E501
            return data

    def get_competition_files_with_http_info(self, competition_id, **kwargs):  # noqa: E501
        """Return a list of the competition files.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_competition_files_with_http_info(competition_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int competition_id: (required)
        :return: Files
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['competition_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_competition_files" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'competition_id' is set
        if ('competition_id' not in params or
                params['competition_id'] is None):
            raise ValueError("Missing the required parameter `competition_id` when calling `get_competition_files`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'competition_id' in params:
            path_params['competitionId'] = params['competition_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearerToken']  # noqa: E501

        return self.api_client.call_api(
            '/competitions/{competitionId}/files', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Files',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_competitions(self, **kwargs):  # noqa: E501
        """Return a list of competitions.  # noqa: E501

        Every inactive competion has been filtered.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_competitions(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: Competitions
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_competitions_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_competitions_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_competitions_with_http_info(self, **kwargs):  # noqa: E501
        """Return a list of competitions.  # noqa: E501

        Every inactive competion has been filtered.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_competitions_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: Competitions
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_competitions" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearerToken']  # noqa: E501

        return self.api_client.call_api(
            '/competitions', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Competitions',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_submission_options(self, **kwargs):  # noqa: E501
        """Return the properties of submission options.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_submission_options(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: SubmissionOptions
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_submission_options_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_submission_options_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_submission_options_with_http_info(self, **kwargs):  # noqa: E501
        """Return the properties of submission options.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_submission_options_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: SubmissionOptions
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_submission_options" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearerToken']  # noqa: E501

        return self.api_client.call_api(
            '/submission-options', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SubmissionOptions',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_competition_agreement(self, competition_id, **kwargs):  # noqa: E501
        """Accept the competition terms of use.  # noqa: E501

        User must accept each competition terms of use.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_competition_agreement(competition_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int competition_id: (required)
        :return: Success
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_competition_agreement_with_http_info(competition_id, **kwargs)  # noqa: E501
        else:
            (data) = self.post_competition_agreement_with_http_info(competition_id, **kwargs)  # noqa: E501
            return data

    def post_competition_agreement_with_http_info(self, competition_id, **kwargs):  # noqa: E501
        """Accept the competition terms of use.  # noqa: E501

        User must accept each competition terms of use.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_competition_agreement_with_http_info(competition_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int competition_id: (required)
        :return: Success
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['competition_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_competition_agreement" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'competition_id' is set
        if ('competition_id' not in params or
                params['competition_id'] is None):
            raise ValueError("Missing the required parameter `competition_id` when calling `post_competition_agreement`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'competition_id' in params:
            path_params['competitionId'] = params['competition_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearerToken']  # noqa: E501

        return self.api_client.call_api(
            '/competitions/{competitionId}/agreement', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Success',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_competition_file(self, competition_id, file_id, **kwargs):  # noqa: E501
        """Return a file url.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_competition_file(competition_id, file_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int competition_id: (required)
        :param int file_id: (required)
        :return: Downloads
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_competition_file_with_http_info(competition_id, file_id, **kwargs)  # noqa: E501
        else:
            (data) = self.post_competition_file_with_http_info(competition_id, file_id, **kwargs)  # noqa: E501
            return data

    def post_competition_file_with_http_info(self, competition_id, file_id, **kwargs):  # noqa: E501
        """Return a file url.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_competition_file_with_http_info(competition_id, file_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int competition_id: (required)
        :param int file_id: (required)
        :return: Downloads
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['competition_id', 'file_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_competition_file" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'competition_id' is set
        if ('competition_id' not in params or
                params['competition_id'] is None):
            raise ValueError("Missing the required parameter `competition_id` when calling `post_competition_file`")  # noqa: E501
        # verify the required parameter 'file_id' is set
        if ('file_id' not in params or
                params['file_id'] is None):
            raise ValueError("Missing the required parameter `file_id` when calling `post_competition_file`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'competition_id' in params:
            path_params['competitionId'] = params['competition_id']  # noqa: E501
        if 'file_id' in params:
            path_params['fileId'] = params['file_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearerToken']  # noqa: E501

        return self.api_client.call_api(
            '/competitions/{competitionId}/files/{fileId}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Downloads',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_competition_files(self, competition_id, **kwargs):  # noqa: E501
        """Return a list of file urls.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_competition_files(competition_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int competition_id: Competition Identifier (required)
        :return: Downloads
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_competition_files_with_http_info(competition_id, **kwargs)  # noqa: E501
        else:
            (data) = self.post_competition_files_with_http_info(competition_id, **kwargs)  # noqa: E501
            return data

    def post_competition_files_with_http_info(self, competition_id, **kwargs):  # noqa: E501
        """Return a list of file urls.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_competition_files_with_http_info(competition_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int competition_id: Competition Identifier (required)
        :return: Downloads
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['competition_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_competition_files" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'competition_id' is set
        if ('competition_id' not in params or
                params['competition_id'] is None):
            raise ValueError("Missing the required parameter `competition_id` when calling `post_competition_files`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'competition_id' in params:
            path_params['competitionId'] = params['competition_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearerToken']  # noqa: E501

        return self.api_client.call_api(
            '/competitions/{competitionId}/files', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Downloads',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_competition_submit(self, competition_id, submission_file, submission_analysis, submission_application, **kwargs):  # noqa: E501
        """Submit file to the competition.  # noqa: E501

        Submit file relative to competition  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_competition_submit(competition_id, submission_file, submission_analysis, submission_application, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int competition_id: (required)
        :param file submission_file: (required)
        :param list[str] submission_analysis: (required)
        :param list[str] submission_application: (required)
        :param str submission_analysis_other:
        :param str submission_application_other:
        :param str submission_note:
        :return: Success
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_competition_submit_with_http_info(competition_id, submission_file, submission_analysis, submission_application, **kwargs)  # noqa: E501
        else:
            (data) = self.post_competition_submit_with_http_info(competition_id, submission_file, submission_analysis, submission_application, **kwargs)  # noqa: E501
            return data

    def post_competition_submit_with_http_info(self, competition_id, submission_file, submission_analysis, submission_application, **kwargs):  # noqa: E501
        """Submit file to the competition.  # noqa: E501

        Submit file relative to competition  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_competition_submit_with_http_info(competition_id, submission_file, submission_analysis, submission_application, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int competition_id: (required)
        :param file submission_file: (required)
        :param list[str] submission_analysis: (required)
        :param list[str] submission_application: (required)
        :param str submission_analysis_other:
        :param str submission_application_other:
        :param str submission_note:
        :return: Success
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['competition_id', 'submission_file', 'submission_analysis', 'submission_application', 'submission_analysis_other', 'submission_application_other', 'submission_note']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_competition_submit" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'competition_id' is set
        if ('competition_id' not in params or
                params['competition_id'] is None):
            raise ValueError("Missing the required parameter `competition_id` when calling `post_competition_submit`")  # noqa: E501
        # verify the required parameter 'submission_file' is set
        if ('submission_file' not in params or
                params['submission_file'] is None):
            raise ValueError("Missing the required parameter `submission_file` when calling `post_competition_submit`")  # noqa: E501
        # verify the required parameter 'submission_analysis' is set
        if ('submission_analysis' not in params or
                params['submission_analysis'] is None):
            raise ValueError("Missing the required parameter `submission_analysis` when calling `post_competition_submit`")  # noqa: E501
        # verify the required parameter 'submission_application' is set
        if ('submission_application' not in params or
                params['submission_application'] is None):
            raise ValueError("Missing the required parameter `submission_application` when calling `post_competition_submit`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'competition_id' in params:
            path_params['competitionId'] = params['competition_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}
        if 'submission_file' in params:
            local_var_files['submission-file'] = params['submission_file']  # noqa: E501
        if 'submission_analysis' in params:
            form_params.append(('submission-analysis[]', params['submission_analysis']))  # noqa: E501
            collection_formats['submission-analysis[]'] = 'multi'  # noqa: E501
        if 'submission_application' in params:
            form_params.append(('submission-application[]', params['submission_application']))  # noqa: E501
            collection_formats['submission-application[]'] = 'multi'  # noqa: E501
        if 'submission_analysis_other' in params:
            form_params.append(('submission-analysis-other', params['submission_analysis_other']))  # noqa: E501
        if 'submission_application_other' in params:
            form_params.append(('submission-application-other', params['submission_application_other']))  # noqa: E501
        if 'submission_note' in params:
            form_params.append(('submission-note', params['submission_note']))  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearerToken']  # noqa: E501

        return self.api_client.call_api(
            '/competitions/{competitionId}/submission', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Success',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



#!/usr/bin/python
#
# Copyright 2019 SIGNATE Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# -*- coding: utf-8 -*-

from setuptools import setup, find_packages
from signate import info
import codecs
import sys

if sys.version_info[:2] < (3, 6):
    raise RuntimeError("Python version >= 3.6 required.")

CLI_REQUIRES = ['click', 'tabulate', 'wget']
SWAGGER_REQUIRES = ['urllib3 >= 1.15', 'six >= 1.10', 'certifi', 'python-dateutil']

setup(
    name='signate',
    version=info.VERSION,
    description=info.NAME,
    url='https://signate.jp',
    long_description=codecs.open('README.md', 'r', 'utf-8').read(),
    long_description_content_type='text/markdown',
    author='SIGNATE Inc.',
    keywords=['signate', 'kaggle', 'cli'],
    entry_points={'console_scripts': ['signate = signate.cli:main']},
    install_requires=CLI_REQUIRES + SWAGGER_REQUIRES,
    python_requires='>=3.6',
    packages=find_packages(exclude=['tests']),
    license='Apache 2.0')
